==> eagle-i-repository-webapp-1.1-MS5.02-sources.jar: jsp/repository/admin/error_jsp.java <==
package jsp.repository.admin;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import java.io.Writer;
import java.io.StringWriter;
import java.io.PrintWriter;
import org.apache.commons.lang.StringEscapeUtils;
import org.apache.log4j.Logger;
import org.apache.log4j.LogManager;

public final class error_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html;charset=UTF-8");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n\n\n\n\n\n\n<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\" xml:lang=\"en\">\n");

    Logger log = LogManager.getLogger("org.eaglei.repository.admin.error.jsp");
    log.debug("Entering error.jsp");
    try {
        Object rawStatus_code = request.getAttribute("javax.servlet.error.status_code");
        String status_code =  rawStatus_code == null ? "(status not set)" : rawStatus_code.toString();
        String uri = (String)request.getAttribute("javax.servlet.error.request_uri");
        String message = (String)request.getAttribute("javax.servlet.error.message");
        Throwable exception = (Throwable)request.getAttribute("javax.servlet.error.exception");
        if (exception == null) {
            exception = (Throwable)request.getAttribute("org.eaglei.repository.error.exception");
        }
        if (message == null) {
            message = "STATUS "+status_code;
        }
        log.debug("status_code="+status_code+", uri="+uri+", msg="+message);
        // for internal failures, leave a record in server log too.
        if (status_code.equals("500")) {
            log.error("Request status is Internal Server Error, stack trace follows:", exception);
        }

      out.write("\n  <head>\n    <title>Data Repository - Error ");
      out.print( status_code );
      out.write("</title>\n   <!--\n    <script type=\"text/javascript\">\n    </script>\n   -->\n    <style>\n<!--\nH1 {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;font-size:22px;}\nH2 {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;font-size:16px;}\nH3 {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;font-size:14px;}\nBODY {font-family:Tahoma,Arial,sans-serif;color:black;background-color:white;}\nB {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;}\nP {font-family:Tahoma,Arial,sans-serif;background:white;color:black;font-size:12px;}\nA {color : black;}\nA.name {color : black;}\nHR {color : #525D76;}\n.show { display: block; }\n.hide { display: none; }\n      -->\n    </style>\n  </head>\n  <body>\n    <h1>Repository HTTP Status ");
      out.print( status_code );
      out.write(' ');
      out.write('-');
      out.write(' ');
      out.print( uri );
      out.write("</h1>\n    <HR size=\"1\" noshade=\"noshade\"/>\n    <p><b>type</b> Status report</p>\n    <p>\n      <b>Message</b>\n      <u>");
      out.print( uri );
      out.write("</u>\n    </p>\n    <p>\n      <b>Description</b>\n      <u>");
      out.print( StringEscapeUtils.escapeHtml(message) );
      out.write("</u>\n    </p>\n    <p>\n      <b>More Details</b>\n      <button type=\"button\"\n              onClick=\" var stackTrace = document.getElementById('stackTrace');\n                        if (stackTrace.className == 'hide') {\n                            stackTrace.className = 'show';\n                            textContent = 'Hide Stack Trace';\n                        } else {\n                            stackTrace.className = 'hide';\n                            textContent = 'Show Stack Trace';\n                        } \">Show Stack Trace</button>\n      </p>\n    <div id=\"stackTrace\" class=\"hide\">\n     <h3>Stack Trace</h3>\n     <pre>\n      ");

        String stackTrace = "(not available)";
        if (exception != null) {
            StringWriter sw = new StringWriter();
            exception.printStackTrace(new PrintWriter(sw));
            stackTrace = sw.toString();
        }
      
      out.write("\n      ");
      out.print( StringEscapeUtils.escapeHtml(stackTrace) );
      out.write("\n     </pre>\n    <HR size=\"1\" noshade=\"noshade\"/>\n  </body>\n");

    } catch (Throwable e) {
        log.error("Got exception during error.jsp processing, OH NOES:",e);
        System.err.println("Got exception during error.jsp processing, OH NOES: "+e);
    }

      out.write("\n</html>\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}

==> eagle-i-repository-webapp-1.2-MS2.01-sources.jar: jsp/repository/admin/error_jsp.java <==
package jsp.repository.admin;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import java.io.Writer;
import java.io.StringWriter;
import java.io.PrintWriter;
import org.apache.commons.lang.StringEscapeUtils;
import org.apache.log4j.Logger;
import org.apache.log4j.LogManager;

public final class error_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html;charset=UTF-8");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n\n\n\n\n\n\n<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\" xml:lang=\"en\">\n");

    Logger log = LogManager.getLogger("org.eaglei.repository.admin.error.jsp");
    log.debug("Entering error.jsp");
    try {
        Object rawStatus_code = request.getAttribute("javax.servlet.error.status_code");
        String status_code =  rawStatus_code == null ? "(status not set)" : rawStatus_code.toString();
        String uri = (String)request.getAttribute("javax.servlet.error.request_uri");
        String message = (String)request.getAttribute("javax.servlet.error.message");
        Throwable exception = (Throwable)request.getAttribute("javax.servlet.error.exception");
        if (exception == null) {
            exception = (Throwable)request.getAttribute("org.eaglei.repository.error.exception");
        }
        if (message == null) {
            message = "STATUS "+status_code;
        }
        log.debug("status_code="+status_code+", uri="+uri+", msg="+message);
        // for internal failures, leave a record in server log too.
        if (status_code.equals("500")) {
            log.error("Request status is Internal Server Error, stack trace follows:", exception);
        }

      out.write("\n  <head>\n    <title>Data Repository - Error ");
      out.print( status_code );
      out.write("</title>\n    <style>\n<!--\nH1 {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;font-size:22px;}\nH2 {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;font-size:16px;}\nH3 {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;font-size:14px;}\nBODY {font-family:Tahoma,Arial,sans-serif;color:black;background-color:white;}\nB {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;}\nP {font-family:Tahoma,Arial,sans-serif;background:white;color:black;font-size:12px;}\nA {color : black;}\nA.name {color : black;}\nHR {color : #525D76;}\n.show { display: block; }\n.hide { display: none; }\n      -->\n    </style>\n  </head>\n  <body>\n    <h1>Repository HTTP Status ");
      out.print( status_code );
      out.write(' ');
      out.write('-');
      out.write(' ');
      out.print( uri );
      out.write("</h1>\n    <HR size=\"1\" noshade=\"noshade\"/>\n    <p><b>type</b> Status report</p>\n    <p>\n      <b>Message</b>\n      <u>");
      out.print( uri );
      out.write("</u>\n    </p>\n    <p>\n      <b>Description</b>\n      <u>");
      out.print( StringEscapeUtils.escapeHtml(message) );
      out.write("</u>\n    </p>\n    <p>\n      <b>More Details</b>\n      <button type=\"button\"\n              onClick=\" var stackTrace = document.getElementById('stackTrace');\n                        if (stackTrace.className == 'hide') {\n                            stackTrace.className = 'show';\n                            textContent = 'Hide Stack Trace';\n                        } else {\n                            stackTrace.className = 'hide';\n                            textContent = 'Show Stack Trace';\n                        } \">Show Stack Trace</button>\n      </p>\n    <div id=\"stackTrace\" class=\"hide\">\n     <h3>Stack Trace</h3>\n     <pre>\n      ");

        String stackTrace = "(not available)";
        if (exception != null) {
            StringWriter sw = new StringWriter();
            exception.printStackTrace(new PrintWriter(sw));
            stackTrace = sw.toString();
        }
      
      out.write("\n      ");
      out.print( StringEscapeUtils.escapeHtml(stackTrace) );
      out.write("\n     </pre>\n    <HR size=\"1\" noshade=\"noshade\"/>\n  </body>\n");

    } catch (Throwable e) {
        log.error("Got exception during error.jsp processing, OH NOES:",e);
        System.err.println("Got exception during error.jsp processing, OH NOES: "+e);
    }

      out.write("\n</html>\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}
